@@ -804,107 +804,6 @@ async fn handle_agreement_on_offline_of_elder() -> Result<()> {
     Ok(())
 }
 
-#[tokio::test]
-async fn handle_unknown_message_from_our_elder() -> Result<()> {
-    handle_unknown_message(UnknownMessageSource::OurElder).await
-}
-
-#[tokio::test]
-async fn handle_unknown_message_from_non_elder() -> Result<()> {
-    handle_unknown_message(UnknownMessageSource::NonElder).await
-}
-
-enum UnknownMessageSource {
-    OurElder,
-    NonElder,
-}
-
-async fn handle_unknown_message(source: UnknownMessageSource) -> Result<()> {
-    let (section_auth, mut nodes) = create_section_auth();
-
-    let (sender_node, expected_recipients) = match source {
-        UnknownMessageSource::OurElder => {
-            // When the unknown message is sent from one of our elders, we should bounce it back to
-            // that elder only.
-            let node = nodes.remove(0);
-            let addr = node.addr;
-            (node, vec![addr])
-        }
-        UnknownMessageSource::NonElder => {
-            // When the unknown message is sent from a peer that is not our elder (including peers
-            // from other sections), bounce it to our elders.
-            (
-                Node::new(
-                    crypto::gen_keypair(&Prefix::default().range_inclusive(), MIN_ADULT_AGE),
-                    gen_addr(),
-                ),
-                section_auth.elders.values().copied().collect(),
-            )
-        }
-    };
-
-    let sk = bls::SecretKey::random();
-    let chain = SectionChain::new(sk.public_key());
-
-    let proven_section_auth = proven(&sk, section_auth)?;
-    let section = Section::new(*chain.root_key(), chain, proven_section_auth)?;
-
-    let node = create_node(MIN_ADULT_AGE);
-    let state = Core::new(node, section, None, mpsc::unbounded_channel().0);
-    let dispatcher = Dispatcher::new(state, create_comm().await?);
-
-    // non-elders can't handle messages addressed to sections.
-    let original_message = Message::single_src(
-        &sender_node,
-        DstLocation::Section(rand::random()),
-        Variant::UserMessage(Bytes::from_static(b"hello")),
-        None,
-        None,
-    )?;
-    let original_message_bytes = original_message.to_bytes();
-
-    let commands = dispatcher
-        .handle_command(Command::HandleMessage {
-            message: original_message,
-            sender: Some(sender_node.addr),
-        })
-        .await?;
-
-    let mut bounce_sent = false;
-
-    // TODO: test also that the message got relayed to the elders.
-
-    for command in commands {
-        let (recipients, message) = if let Command::SendMessage {
-            recipients,
-            message: MessageType::NodeMessage(NodeMessage(msg_bytes)),
-            ..
-        } = command
-        {
-            (recipients, Message::from_bytes(Bytes::from(msg_bytes))?)
-        } else {
-            continue;
-        };
-
-        let (src_key, message) =
-            if let Variant::BouncedUnknownMessage { src_key, message } = message.variant() {
-                (src_key, message)
-            } else {
-                continue;
-            };
-
-        assert_eq!(recipients, expected_recipients);
-        assert_eq!(*src_key, sk.public_key());
-        assert_eq!(*message, original_message_bytes);
-
-        bounce_sent = true;
-    }
-
-    assert!(bounce_sent);
-
-    Ok(())
-}
-
 #[tokio::test]
 async fn handle_untrusted_message_from_peer() -> Result<()> {
     handle_untrusted_message(UntrustedMessageSource::Peer).await
@@ -1008,102 +907,6 @@ async fn handle_untrusted_message(source: UntrustedMessageSource) -> Result<()>
     Ok(())
 }
 
-#[tokio::test]
-async fn handle_bounced_unknown_message() -> Result<()> {
-    let (section_auth, mut nodes) = create_section_auth();
-
-    // Create section chain with two keys.
-    let sk0 = bls::SecretKey::random();
-    let pk0 = sk0.public_key();
-
-    let sk1_set = SecretKeySet::random();
-    let pk1 = sk1_set.secret_key().public_key();
-    let pk1_signature = sk0.sign(&bincode::serialize(&pk1)?);
-
-    let mut section_chain = SectionChain::new(pk0);
-    let _ = section_chain.insert(&pk0, pk1, pk1_signature);
-
-    let proven_section_auth = proven(sk1_set.secret_key(), section_auth)?;
-    let section = Section::new(pk0, section_chain, proven_section_auth)?;
-    let section_key_share = create_section_key_share(&sk1_set, 0);
-
-    let node = nodes.remove(0);
-
-    // Create the original message whose bounce we want to test. The content of the message doesn't
-    // matter for the purpose of this test.
-    let other_node = Node::new(
-        crypto::gen_keypair(&Prefix::default().range_inclusive(), MIN_ADULT_AGE),
-        gen_addr(),
-    );
-    let original_message_content = Bytes::from_static(b"unknown message");
-    let original_message = Message::single_src(
-        &node,
-        DstLocation::Node(other_node.name()),
-        Variant::UserMessage(original_message_content.clone()),
-        None,
-        None,
-    )?;
-
-    let state = Core::new(
-        node,
-        section,
-        Some(section_key_share),
-        mpsc::unbounded_channel().0,
-    );
-    let dispatcher = Dispatcher::new(state, create_comm().await?);
-
-    let bounced_message = Message::single_src(
-        &other_node,
-        DstLocation::Direct,
-        Variant::BouncedUnknownMessage {
-            src_key: pk0,
-            message: original_message.to_bytes(),
-        },
-        None,
-        None,
-    )?;
-
-    let commands = dispatcher
-        .handle_command(Command::HandleMessage {
-            message: bounced_message,
-            sender: Some(other_node.addr),
-        })
-        .await?;
-
-    let mut sync_sent = false;
-    let mut original_message_sent = false;
-
-    for command in commands {
-        let (recipients, message) = match command {
-            Command::SendMessage {
-                recipients,
-                message: MessageType::NodeMessage(NodeMessage(msg_bytes)),
-                ..
-            } => (recipients, Message::from_bytes(Bytes::from(msg_bytes))?),
-            _ => continue,
-        };
-
-        match message.variant() {
-            Variant::Sync { section, .. } => {
-                assert_eq!(recipients, [other_node.addr]);
-                assert_eq!(*section.chain().last_key(), pk1);
-                sync_sent = true;
-            }
-            Variant::UserMessage(content) => {
-                assert_eq!(recipients, [other_node.addr]);
-                assert_eq!(*content, original_message_content);
-                original_message_sent = true;
-            }
-            _ => continue,
-        }
-    }
-
-    assert!(sync_sent);
-    assert!(original_message_sent);
-
-    Ok(())
-}
-
 #[tokio::test]
 async fn handle_bounced_untrusted_message() -> Result<()> {
     let (section_auth, mut nodes) = create_section_auth();
